==> android-sdk-2.3.1.8-sources.jar: io/adbrix/sdk/component/AbxLog.java <==
package io.adbrix.sdk.component;

import android.content.Context;
import android.content.pm.PackageManager;
import android.util.Log;

import java.util.Arrays;
import io.adbrix.sdk.domain.ABXConstants;
import io.adbrix.sdk.utils.CommonUtils;

public class AbxLog {

    private static IPairObserver<Integer, String> logObserver;
    public static final int MAX_LOG_LENGTH = 10000;

    private static boolean qaLogEnable = false;

    private AbxLog() {
    }

    public static void setQAMode(boolean qaMode){
        AbxLog.qaLogEnable = qaMode;
    }

    public static void checkDebugAppInstalled(Context context) {
        //개발시엔 디버깅 앱 설치
        AbxLog.qaLogEnable = checkPkgInstall(context);

        if (AbxLog.qaLogEnable)
            AbxLog.d("QA MODE!", true);
    }

    public static void v(String msg, boolean qaModeOnly) {
        notifyObserver(Log.VERBOSE, msg);

        if (!AbxLog.qaLogEnable) {
            return;
        }
        Log.v(ABXConstants.LOGTAG, msg);
    }

    public static void d(String msg, boolean qaModeOnly) {
        notifyObserver(Log.DEBUG, msg);

        if (!AbxLog.qaLogEnable) {
            return;
        }
        if (msg.length() > 4000) largeLog(ABXConstants.LOGTAG, msg);
        else Log.d(ABXConstants.LOGTAG, msg);
    }

    public static void i(String msg, boolean qaModeOnly) {
        notifyObserver(Log.INFO, msg);

        if (!AbxLog.qaLogEnable) {
            return;
        }
        Log.i(ABXConstants.LOGTAG, msg);
    }

    public static void w(String msg, boolean qaModeOnly) {
        notifyObserver(Log.WARN, msg);

        if (!AbxLog.qaLogEnable) {
            return;
        }
        Log.w(ABXConstants.LOGTAG, msg);
    }

    public static void w(Exception e, boolean qaModeOnly) {
        StringBuilder builder = new StringBuilder();
        builder.append("[");
        builder.append(e.toString());
        builder.append("] ");
        String threadName = Thread.currentThread().getName();
        if(!CommonUtils.isNullOrEmpty(threadName)){
            builder.append("Thread: ");
            builder.append(threadName);
        }
        StackTraceElement[] elements = e.getStackTrace();
        if(!CommonUtils.isNullOrEmpty(elements)){
            builder.append("\n");
            builder.append(Arrays.toString(elements));
        }
        String msg = builder.toString();
        notifyObserver(Log.WARN, msg);
        if (!AbxLog.qaLogEnable) {
            return;
        }
        Log.w(ABXConstants.LOGTAG, msg);
    }

    public static void w(String msg, Exception e, boolean qaModeOnly) {
        StringBuilder builder = new StringBuilder();
        builder.append("[");
        builder.append(e.toString());
        builder.append("]");
        String threadName = Thread.currentThread().getName();
        if(!CommonUtils.isNullOrEmpty(threadName)){
            builder.append(" Thread: ");
            builder.append(threadName);
        }
        builder.append(" Message: ");
        builder.append(msg);
        StackTraceElement[] elements = e.getStackTrace();
        if(!CommonUtils.isNullOrEmpty(elements)){
            builder.append("\n");
            builder.append(Arrays.toString(elements));
        }
        String result = builder.toString();
        notifyObserver(Log.WARN, result);
        if (!AbxLog.qaLogEnable) {
            return;
        }
        Log.w(ABXConstants.LOGTAG, result);
    }

    public static void e(String msg, boolean qaModeOnly) {
        notifyObserver(Log.ERROR, msg);

        if (!AbxLog.qaLogEnable) {
            return;
        }
        Log.e(ABXConstants.LOGTAG, msg);
    }

    public static void e(Exception e, boolean qaModeOnly) {
        StringBuilder builder = new StringBuilder();
        builder.append("[");
        builder.append(e.toString());
        builder.append("] ");
        String threadName = Thread.currentThread().getName();
        if(!CommonUtils.isNullOrEmpty(threadName)){
            builder.append("Thread: ");
            builder.append(threadName);
        }
        StackTraceElement[] elements = e.getStackTrace();
        if(!CommonUtils.isNullOrEmpty(elements)){
            builder.append("\n");
            builder.append(Arrays.toString(elements));
        }
        String msg = builder.toString();
        notifyObserver(Log.ERROR, msg);
        if (!AbxLog.qaLogEnable) {
            return;
        }
        Log.e(ABXConstants.LOGTAG, msg);
    }

    public static void e(String msg, Exception e, boolean qaModeOnly) {
        StringBuilder builder = new StringBuilder();
        builder.append("[");
        builder.append(e.toString());
        builder.append("]");
        String threadName = Thread.currentThread().getName();
        if(!CommonUtils.isNullOrEmpty(threadName)){
            builder.append(" Thread: ");
            builder.append(threadName);
        }
        builder.append(" Message: ");
        builder.append(msg);
        StackTraceElement[] elements = e.getStackTrace();
        if(!CommonUtils.isNullOrEmpty(elements)){
            builder.append("\n");
            builder.append(Arrays.toString(elements));
        }
        String result = builder.toString();
        notifyObserver(Log.ERROR, result);
        if (!AbxLog.qaLogEnable) {
            return;
        }
        Log.e(ABXConstants.LOGTAG, result);
    }
    private static boolean checkPkgInstall(Context context) {
        try {
            PackageManager pm = context.getPackageManager();
            String adbrixRmDebugApp = "com.igaworks.adbrixrm.debug";
            pm.getApplicationInfo(adbrixRmDebugApp, 0);
            return true;
        } catch (Exception e) {
            return false;
        }
    }

    private static void largeLog(String tag, String content) {
        String limitedContent;
        if (content.length() > MAX_LOG_LENGTH) {
            limitedContent = content.substring(0, MAX_LOG_LENGTH);
        } else {
            limitedContent = content;
        }

        if (limitedContent.length() > 4000) {
            Log.d(tag, limitedContent.substring(0, 4000));
            largeLog(tag, limitedContent.substring(4000));
        } else {
            Log.d(tag, limitedContent);
        }
    }

    public static void setLogObserver(IPairObserver<Integer, String> observer) {
        logObserver = observer;
    }

    private static void notifyObserver(Integer level, String message) {
        if (logObserver != null)
            logObserver.update(level, message);
    }
}

==> android-sdk-2.4.0.2-sources.jar: io/adbrix/sdk/component/AbxLog.java <==
package io.adbrix.sdk.component;

import android.content.Context;
import android.content.pm.PackageManager;
import android.util.Log;

import java.util.Arrays;
import io.adbrix.sdk.domain.ABXConstants;
import io.adbrix.sdk.utils.CommonUtils;

public class AbxLog {
    private static IPairObserver<Integer, String> logObserver;
    public static final int MAX_LOG_LENGTH = 10000;

    private static boolean qaLogEnable = false;

    private AbxLog() {
    }

    public static void setQAMode(boolean qaMode){
        AbxLog.qaLogEnable = qaMode;
    }

    public static void checkDebugAppInstalled(Context context) {
        //개발시엔 디버깅 앱 설치
        AbxLog.qaLogEnable = checkPkgInstall(context);

        if (AbxLog.qaLogEnable)
            AbxLog.d("QA MODE!", true);
    }

    public static void v(String msg, boolean qaModeOnly) {
        notifyObserver(Log.VERBOSE, msg);

        if (!AbxLog.qaLogEnable) {
            return;
        }
        largeLog(ABXConstants.LOGTAG, msg, Log.VERBOSE);
    }

    public static void d(String msg, boolean qaModeOnly) {
        notifyObserver(Log.DEBUG, msg);

        if (!AbxLog.qaLogEnable) {
            return;
        }
        largeLog(ABXConstants.LOGTAG, msg, Log.DEBUG);
    }

    public static void i(String msg, boolean qaModeOnly) {
        notifyObserver(Log.INFO, msg);

        if (!AbxLog.qaLogEnable) {
            return;
        }
        largeLog(ABXConstants.LOGTAG, msg, Log.INFO);
    }

    public static void w(String msg, boolean qaModeOnly) {
        notifyObserver(Log.WARN, msg);

        if (!AbxLog.qaLogEnable) {
            return;
        }
        largeLog(ABXConstants.LOGTAG, msg, Log.WARN);
    }

    public static void w(Exception e, boolean qaModeOnly) {
        StringBuilder builder = new StringBuilder();
        builder.append("[");
        builder.append(e.toString());
        builder.append("] ");
        String threadName = Thread.currentThread().getName();
        if(!CommonUtils.isNullOrEmpty(threadName)){
            builder.append("Thread: ");
            builder.append(threadName);
        }
        StackTraceElement[] elements = e.getStackTrace();
        if(!CommonUtils.isNullOrEmpty(elements)){
            builder.append("\n");
            builder.append(Arrays.toString(elements));
        }
        String msg = builder.toString();
        notifyObserver(Log.WARN, msg);
        if (!AbxLog.qaLogEnable) {
            return;
        }
        largeLog(ABXConstants.LOGTAG, msg, Log.WARN);
    }

    public static void w(String msg, Exception e, boolean qaModeOnly) {
        StringBuilder builder = new StringBuilder();
        builder.append("[");
        builder.append(e.toString());
        builder.append("]");
        String threadName = Thread.currentThread().getName();
        if(!CommonUtils.isNullOrEmpty(threadName)){
            builder.append(" Thread: ");
            builder.append(threadName);
        }
        builder.append(" Message: ");
        builder.append(msg);
        StackTraceElement[] elements = e.getStackTrace();
        if(!CommonUtils.isNullOrEmpty(elements)){
            builder.append("\n");
            builder.append(Arrays.toString(elements));
        }
        String result = builder.toString();
        notifyObserver(Log.WARN, result);
        if (!AbxLog.qaLogEnable) {
            return;
        }
        largeLog(ABXConstants.LOGTAG, result, Log.WARN);
    }

    public static void e(String msg, boolean qaModeOnly) {
        notifyObserver(Log.ERROR, msg);

        if (!AbxLog.qaLogEnable) {
            return;
        }
        largeLog(ABXConstants.LOGTAG, msg, Log.ERROR);
    }

    public static void e(Exception e, boolean qaModeOnly) {
        StringBuilder builder = new StringBuilder();
        builder.append("[");
        builder.append(e.toString());
        builder.append("] ");
        String threadName = Thread.currentThread().getName();
        if(!CommonUtils.isNullOrEmpty(threadName)){
            builder.append("Thread: ");
            builder.append(threadName);
        }
        StackTraceElement[] elements = e.getStackTrace();
        if(!CommonUtils.isNullOrEmpty(elements)){
            builder.append("\n");
            builder.append(Arrays.toString(elements));
        }
        String msg = builder.toString();
        notifyObserver(Log.ERROR, msg);
        if (!AbxLog.qaLogEnable) {
            return;
        }
        largeLog(ABXConstants.LOGTAG, msg, Log.ERROR);
    }

    public static void e(String msg, Exception e, boolean qaModeOnly) {
        StringBuilder builder = new StringBuilder();
        builder.append("[");
        builder.append(e.toString());
        builder.append("]");
        String threadName = Thread.currentThread().getName();
        if(!CommonUtils.isNullOrEmpty(threadName)){
            builder.append(" Thread: ");
            builder.append(threadName);
        }
        builder.append(" Message: ");
        builder.append(msg);
        StackTraceElement[] elements = e.getStackTrace();
        if(!CommonUtils.isNullOrEmpty(elements)){
            builder.append("\n");
            builder.append(Arrays.toString(elements));
        }
        String result = builder.toString();
        notifyObserver(Log.ERROR, result);
        if (!AbxLog.qaLogEnable) {
            return;
        }
        largeLog(ABXConstants.LOGTAG, result, Log.ERROR);
    }
    private static boolean checkPkgInstall(Context context) {
        try {
            PackageManager pm = context.getPackageManager();
            String adbrixRmDebugApp = "com.igaworks.adbrixrm.debug";
            pm.getApplicationInfo(adbrixRmDebugApp, 0);
            return true;
        } catch (Exception e) {
            return false;
        }
    }

    private static void largeLog(String tag, String content, int type) {
        String limitedContent;
        if (content.length() > MAX_LOG_LENGTH) {
            limitedContent = content.substring(0, MAX_LOG_LENGTH);
        } else {
            limitedContent = content;
        }

        if (limitedContent.length() > 4000) {
            log(tag, limitedContent.substring(0, 4000), type);
            largeLog(tag, limitedContent.substring(4000), type);
        } else {
            log(tag, limitedContent, type);
        }
    }
    private static void log(String tag, String content, int type){
        switch (type){
            case Log.VERBOSE:
                Log.v(tag, content);
                break;
            case Log.DEBUG:
                Log.d(tag, content);
                break;
            case Log.INFO:
                Log.i(tag, content);
                break;
            case Log.WARN:
                Log.w(tag, content);
                break;
            case Log.ERROR:
                Log.e(tag, content);
                break;
            case Log.ASSERT:
                Log.wtf(tag, content);
                break;
        }
    }

    public static void setLogObserver(IPairObserver<Integer, String> observer) {
        logObserver = observer;
    }

    private static void notifyObserver(Integer level, String message) {
        if (logObserver != null)
            logObserver.update(level, message);
    }
}
